import { shrink } from '@zazuko/prefixes';
import { xsd } from '@tpluscode/rdf-ns-builders';
import { mapBuilders } from '../prefixes.js';
import * as ntriples from './ntriples.js';
export function blankNode(term) {
    return ntriples.blankNode(term);
}
export function namedNode(term, { base = '', prefixes = {}, noPrefixedNames }) {
    const baseStr = (typeof base === 'string') ? base : base.value;
    const baseRegex = new RegExp('^' + baseStr);
    let shrunk;
    if (noPrefixedNames !== true && (shrunk = shrink(term.value, mapBuilders(prefixes)))) {
        return {
            value: shrunk.replaceAll(/[/#]/g, s => `\\${s}`),
            prefixes: [
                shrunk.split(':')[0],
            ],
        };
    }
    return {
        value: `<${term.value.replace(baseRegex, '')}>`,
        prefixes: [],
    };
}
function isBuiltInType(datatype) {
    return datatype.equals(xsd.integer) || datatype.equals(xsd.boolean) || datatype.equals(xsd.decimal);
}
export function literal(term, { base = '', prefixes = {} }) {
    if (!term.language && term.datatype) {
        if (isBuiltInType(term.datatype)) {
            return {
                value: term.value,
                prefixes: [],
            };
        }
        if (!term.datatype.equals(xsd.string)) {
            const datatypeResult = namedNode(term.datatype, { base, prefixes });
            return {
                value: `${ntriples.literalValue(term)}^^${datatypeResult.value}`,
                prefixes: datatypeResult.prefixes,
            };
        }
    }
    return {
        value: ntriples.literal(term),
        prefixes: [],
    };
}
